@@ -28,6 +28,7 @@ class Corpus(object):
 	XML2TXT = default_xml2txt
 
 	def __init__(self,load_meta=False,**attrs):
+		self.id,self.name,self.path_root,self.path_metadata=None,None,None,None
 		self._metadf=None
 		self._texts=None
 		self._textd=None
@@ -41,6 +42,12 @@ class Corpus(object):
 				self.load_metadata()
 			except Exception:
 				pass
+		if not self.path_root and self.id:
+			self.path_root=os.path.join(PATH_CORPUS,self.id)
+		if not self.path_metadata and self.id:
+			self.path_metadata=os.path.join(PATH_CORPUS,self.id,'metadata.csv')
+
+
 	#####
 	# Metadata
 	####
@@ -108,7 +115,11 @@ class Corpus(object):
 
 	@property
 	def meta(self):
-		if self._metadf is None: self.load_metadata()
+		if self._metadf is None:
+			try:
+				self.load_metadata()
+			except Exception:
+				pass
 		return self._metadf if self._metadf is not None else pd.DataFrame()
 	@property
 	def metadf(self):
